@@ -489,14 +489,14 @@ class ParametersLEDET:
                 print(k, self.getAttribute(variableGroup, k))
         else:
             self.variableGroupInputs = asdict(self.Inputs)
-            print(self.variableGroupInputs)
             self.variableGroupOptions = asdict(self.Options)
             self.variableGroupPlots = asdict(self.Plots)
             self.variableGroupVariables = asdict(self.Variables)
             for k in variableGroup:
                 if (k == "BlankRows"): continue
                 print(variableGroup[k])
-                print(k, variableGroup[k])
+                print(k)
+               # print(k, variableGroup[k])
 
     def getNumberOfCoilSections(self):
         k = self.Inputs.M_m
