@@ -9,14 +9,15 @@ import time
 testfile1 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MBRC\MBRC_0.xlsx"
 testfile2 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MBRB\MBRB_0.xlsx"
 testfile3 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MBRS\MBRS_0.xlsx"
-testfile4 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCD\MCD_0.xlsx"
-testfile5 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCO\MCO_0.xlsx"
-testfile6 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MO_1AP\MO_1AP_8magBB_0.xlsx"
-testfile7 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCBXH\MCBXH_CopperWedges_ThCool_0.xlsx"
-testfile8 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCBXV\MCBXV_CopperWedges_ThCool_0.xlsx"
-testfile9 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCBXV\MCBXV_CopperWedges_0.xlsx"
-testfile10 = "C:\cernbox\TEMP2\MCBY_1AP_CopperWedges_ThCool_29.xlsx"
-testfile11 = "C:\cernbox\LEDET\LEDET\MCBY_1AP_CopperWedges_ThCool\Input\MCBY_1AP_CopperWedges_ThCool_35.xlsx"
+testfile4 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MBX\MBX_0.xlsx"
+testfile5 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCD\MCD_0.xlsx"
+testfile6 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCO\MCO_0.xlsx"
+testfile7 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MO_1AP\MO_1AP_8magBB_0.xlsx"
+testfile8 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCBXH\MCBXH_CopperWedges_ThCool_0.xlsx"
+testfile9 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCBXV\MCBXV_CopperWedges_ThCool_0.xlsx"
+testfile10 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCBXV\MCBXV_CopperWedges_0.xlsx"
+testfile11 = "C:\cernbox\TEMP2\MCBY_1AP_CopperWedges_ThCool_29.xlsx"
+testfile12 = "C:\cernbox\LEDET\LEDET\MCBY_1AP_CopperWedges_ThCool\Input\MCBY_1AP_CopperWedges_ThCool_35.xlsx"
 
 ledetFolder = 'C:\cernbox\LEDET\\'
 ledetExe = 'LEDET_v1_07_02_02_25May2020.exe'
@@ -24,9 +25,9 @@ ledetExe = 'LEDET_v1_07_02_02_25May2020.exe'
 def CompleteRun():
     start = time.time()
     a = ParametersLEDET()
-    a.readLEDETExcel(testfile11)
-    Sw = MinMaxSweep(a, 6)
-    MagnetName = 'MCBY_1AP_CopperWedges_ThCool'
+    a.readLEDETExcel(testfile9)
+    Sw = MinMaxSweep(a, 10)
+    MagnetName = 'MCBXH_CopperWedges_ThCool'
 
     ##8mag
     # Sw.addParameterToSweep('l_magnet', 2.56, 4.8)
@@ -37,11 +38,11 @@ def CompleteRun():
     # Sw.addParameterToSweep('f_ro_eff_inGroup', 1, 3)
     # Sw.addParameterToSweep('RRR_Cu_inGroup', 100, 300)
 
-    # ##MBX
+    # ##MBX/ MRBC/ MBRS/ MBRB
     # Sw.addParameterToSweep('f_ro_eff_inGroup', 1, 3, basePoints = 3)
     # Sw.addParameterToSweep('R_c_inGroup', -6, -3, type='logarithmic', basePoints= 3)
-    # Sw.addHeliumCrossSection(9.43646062, 0, 6, basePoints=4)
-    # Sw.addParameterToSweep('RRR_Cu_inGroup', 38, 200, basePoints=6)
+    # Sw.addHeliumCrossSection(0, 6, basePoints= 4)
+    # Sw.addParameterToSweep('RRR_Cu_inGroup', 35, 200, basePoints=6)
 
     ##8mag
     # Sw.addParameterToSweep('l_magnet', 0.056, 0.14)
@@ -50,23 +51,25 @@ def CompleteRun():
     # Sw.addHeliumCrossSection(3, 6, basePoints=4)
 
     ## MCBXH_CopperWedges -1
-    # Sw.addParameterToSweep('f_ro_eff_inGroup', 0.3, 2.5)
-    # Sw.addParameterToSweep('RRR_Cu_inGroup', 100, 300)
+    Sw.addParameterToSweep('f_ro_eff_inGroup', 0.1, 3)
+    Sw.addParameterToSweep('RRR_Cu_inGroup', 100, 300)
+    # Sw.addParameterToSweep('l_magnet', 0.056, 0.14)
     # Sw.addQuenchSweep("tStartQuench",[1,1,1,1,1,1],[-0.2, -0.21, -0.22, -0.23, -0.24, -0.25])
     # Sw.addQuenchSweep("tStartQuench", [[1, 730],[321,1050],[1, 730],[321,1050],[1, 730],[321,1050],[1, 730],[321,1050]],
     #                   [[-0.2, -0.182],[-0.2, -0.182],[-0.15, -0.132],[-0.15, -0.132],[-0.1, -0.082],[-0.2, -0.082],[-0.05, -0.032],[-0.05, -0.032]])
 
     ##MCBY
     # Sw.addParameterToSweep('f_ro_eff_inGroup', 1, 3)
-    Sw.addParameterToSweep('RRR_Cu_inGroup', 100, 300)
+    # Sw.addParameterToSweep('RRR_Cu_inGroup', 100, 300)
 
     ## Current Sweep
-    # Sw.addCurrentSweep(120, 13)
+    # Sw.addCurrentSweep(6650, 30)
 
     Sw.generatePermutations()
     end = time.time()
     print("Time:", end-start)
     start = time.time()
+    # Sw.prepareSimulation(MagnetName, "C:\\cernbox\\TEMP2\\",OffsetNumber=100)
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MBRC\\Input\\")
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MCD\\Input\\")
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MCO\\Input\\")
@@ -75,14 +78,14 @@ def CompleteRun():
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MCBXV_CopperWedges_ThCool\\Input\\")
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\\TEMP2\\", OffsetNumber= 42, ROXIE_File='C:\\cernbox\\SWAN_projects\\steam-notebooks\\steam-ledet-input\\MCBXV\\MCBXV_CopperWedges_All_WithIron_WithSelfField.map2d')
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\\TEMP2\\", OffsetNumber=17, ROXIE_File='C:\\cernbox\\SWAN_projects\\steam-notebooks\\steam-ledet-input\\MCBY_1AP\\MCBY_1AP_CopperWedges_ThCool_All_WithIron_WithSelfField.map2d')
-    Sw.prepareSimulation(MagnetName, "C:\\cernbox\\TEMP2\\", OffsetNumber=50)
+    # Sw.prepareSimulation(MagnetName, "C:\\cernbox\\TEMP2\\", OffsetNumber=50)
 
 
     end = time.time()
     print("Time:", end - start)
     print("Preparation done")
 
-    # RunSimulations(ledetFolder, ledetExe, 'MCBXV_CopperWedges_ThCool', RunSimulations=False)
+    # RunSimulations(ledetFolder, ledetExe, MagnetName, RunSimulations=False)
     # EvaluateSimulations("C:\\cernbox\\LEDET\\LEDET\\MCO\\Output\\Txt Files", 'MCO',
     #                     'C:\\cernbox\\Validation_MCDO\\Exp Data\\RCO.A56B1_2018-03-16_PM_I_A_AutoAlign.csv',
     #                     Sw, Mat=False, SkipAlign=True)
@@ -92,6 +95,9 @@ def CompleteRun():
     # EvaluateSimulations('C:\cernbox\LEDET\LEDET_SimulationFiles_Quench\LEDET\MBRS\Output\Txt Files', 'MBRS',
     #                      'C:\cernbox\Validation_IPD\Validation MBRS\Exp Data\RD3.R4_20181203_135959_IA - Cut.csv',
     #                     Sw, Mat=False, SkipAlign=True)
+    # EvaluateSimulations('C:\cernbox\LEDET\LEDET\MBRC\Output\Txt Files', 'MBRC',
+    #                      'C:\cernbox\Validation_IPD\Validation MBRC\Exp Data\RD2.L8_20181203_131307_IA - Cut.csv',
+    #                     Sw, Mat=False)
     # EvaluateSimulations('C:\\cernbox\\Validation_MO\\Validation\\LEDET\\FullB2', 'MO_1AP', 'C:\\cernbox\\LHC-SM-API\\ROD_ROF\\ROD.A12B2_PM_I_A.csv',
     #                     Sw, Mat=False)
     # EvaluateSimulations('C:\\cernbox\\Validation_MO\\Validation\\LEDET\\FullB1', 'MO_1AP',
@@ -103,9 +109,13 @@ def CompleteRun():
     # EvaluateSimulations('C:\\cernbox\\Validation_MCBX_HV\\LEDET Validation\\2nd Sweep-RRR_fro_tQ_THCOOL\\Output\\Txt Files',
     #                     'MCBXH_CopperWedges_ThCool', 'C:\\cernbox\\Validation_MCBX_HV\\Exp Data\\RCBXH1.R1_2018-03-11_PM_I_ARAW.csv',
     #                      Sw, Mat=False, showBestFit = 20)
-    # EvaluateSimulations('C:\\cernbox\\LEDET\\LEDET\\MCBXV_CopperWedges_ThCool\\Output\\Txt Files',
-    #                     'MCBXV_CopperWedges_ThCool', 'C:\\cernbox\\Validation_MCBX_HV\\Exp Data\\RCBXV2.R1_2017-04-20_PM_I_ARAW.csv',
-    #                      Sw, Mat=False, showBestFit = 20)
+    EvaluateSimulations("C:\\cernbox\\TEMP\\",
+                        'MCBXV_CopperWedges_ThCool', 'C:\\cernbox\\Validation_MCBX_HV\\Exp Data\\RCBXV2.R1_2017-04-20_PM_I_ARAW.csv',
+                         Sw, Mat=False)
+    # EvaluateSimulations("C:\\cernbox\\TEMP2\\",
+    #                     'MCBXH_CopperWedges_ThCool',
+    #                     'C:\\cernbox\\Validation_MCBX_HV\\Exp Data\\RCBXH1.R1_2018-03-11_PM_I_ARAW.csv',
+    #                     Sw, Mat=False)
 
 def AutomaticRun():
     LEDETFolder = 'C:\\cernbox\LEDET\\LEDET_SimulationFiles_Quench'
