@@ -440,7 +440,7 @@ class ParametersCOSIM:
 
     def copyCOSIMfiles(self, circuit, nameFileSING, StimulusFile, LEDETFiles, nameMagnet,N_LEDET=1):
         nameFolderCosimModel = self.nameFolderCosimModel
-        print(nameFolderCosimModel)
+        #print(nameFolderCosimModel)
         # Copy PSPICE model file
         nameFolderPSpiceModel = os.path.join(nameFolderCosimModel, 'PSpice')
         if not os.path.isdir(nameFolderPSpiceModel):
@@ -450,7 +450,6 @@ class ParametersCOSIM:
 
         LEDET_Fs = []
         for i in range(N_LEDET):
-            # Copy LEDET model files - MCD
             if N_LEDET > 1:
                 nameFolderLedetModel = os.path.join(nameFolderCosimModel, 'LEDET_'+str(i+1))
                 if len(LEDETFiles)>1:
@@ -474,7 +473,10 @@ class ParametersCOSIM:
                     makeCopyFile(os.path.join(sourcedir, file), os.path.join(destinationpath_field, file))
                 if file.endswith('.xlsx') and not file.startswith(".sys") and file.startswith(str(nM)):
                     shutil.copy(os.path.join(sourcedir, file), os.path.join(destinationpath_para, file))
-                    LEDET_Fs.append(file)
+                    if len(LEDETFiles) > 1:
+                        LEDET_Fs.append(LEDETFiles[i]+file)
+                    else:
+                        LEDET_Fs.append(LEDETFiles+file)
                 if file.endswith('_selfMutualInductanceMatrix.csv'):
                     shutil.copy(os.path.join(sourcedir, file), os.path.join(destinationpath_para, file))
 
